@@ -127,10 +127,7 @@
   void IntField::empty() { i=0; }
   int IntField::get() const { return i; }
   void IntField::get(Str& s) const {
-  	char *c;
-  	asprintf(&c, "%i", i);
-		s+=c;
-		free(c);
+		s+=i;
 	}	
   void IntField::set(int j) { i=j; }
   void IntField::set(const char *s) { i=strtol(s,0,0); }
@@ -1328,10 +1325,14 @@ PublisherName *KaspaBase::getPublisherNames(const char *where) {
     s+=where;
     exec(s);
     for(int i=0; i<tuples(); i++) {
+    	if(strcmp(getValue(i, "serie"), ""))
+    		continue;
       PublisherName *rec=new PublisherName;
+/*
 			rec->title.set(getValue(i, "serie"));
 			if(!strlen(rec->title.get()))
-	      rec->title.set(getValue(i, "name"));
+*/			
+	    rec->title.set(getValue(i, "name"));
       rec->address.set(getValue(i, "city"));
       rec->table.set("publisher");
       rec->o.set(getValue(i, "oid"));
@@ -1348,6 +1349,39 @@ PublisherName *KaspaBase::getPublisherNames(const char *where) {
   return last;	
 }
 
+
+JournalName *KaspaBase::getJournalNames(const char *where) {
+  JournalName *last=0;
+  try {
+    exec("begin");
+    Str s("select oid, name, city, serie from publisher ");
+    s+=where;
+    exec(s);
+    for(int i=0; i<tuples(); i++) {
+    	if(!strcmp(getValue(i, "serie"), ""))
+    		continue;
+      JournalName *rec=new JournalName;
+			rec->title.set(getValue(i, "serie"));
+/*			if(!strlen(rec->title.get()))
+	      rec->title.set(getValue(i, "name"));
+*/	
+      rec->address.set(getValue(i, "city"));
+      rec->table.set("publisher");
+      rec->o.set(getValue(i, "oid"));
+      rec->next=last;
+      last=rec;
+    }
+    exec("commit");
+  } catch(...) {
+    delete last;
+    last=0L;
+    exec("rollback");
+    throw;
+  }
+  return last;	
+}
+
+
 /**  */
 void KaspaBase::search(const char *where, AuthorName **an, PartTitle **pt,
 									PublTitle **pbt, NoteTitle **nt, PartDataName **pdt) {
