@@ -20,7 +20,7 @@
 #ifdef HAVE_CONFIG_H
 #include <config.h>
 #endif
-#include "sql.h"
+#include "kaspasql.h"
 #include <stdio.h>
 
 
@@ -266,6 +266,14 @@ public:
 	const char *getAddress() { return address.get(); }
 };
 
+class JournalName: public Title {
+friend KaspaBase;
+	TextField address;
+public:
+  virtual JournalName *getNext() { return (JournalName *)next; }
+	const char *getAddress() { return address.get(); }
+};
+
 class NoteTitle: public Title {
 friend KaspaBase;
 	OidField publno;
@@ -677,6 +685,9 @@ class KaspaBase : private Sql {
   		(o=oid, s1=name, s2="")
 	*/
 	PublisherName *getPublisherNames(const char *where);
+	
+	JournalName *getJournalNames(const char *where);
+	
   /**  */
 	void search(const char *where, AuthorName **an, PartTitle **pt,
 				PublTitle **pbt, NoteTitle **nt, PartDataName **pdt);
