@@ -391,10 +391,20 @@ void Bibliography::generateBibTex() {
 
 	QString publisher;
 	QString address;
-	PublisherName *pn=publ->getPublisher();
-	if(pn) {
-		publisher=pn->getTitle();
-		address=pn->getAddress();
+  if(publ->getEntryType()==BT_ARTICLE) {
+  	JournalName *jn=publ->getJournal();
+  	if(jn) {
+  		publisher=jn->getTitle();
+			address=jn->getAddress();
+			delete jn;
+		}
+	} else {
+		PublisherName *pn=publ->getPublisher();
+		if(pn) {
+			publisher=pn->getTitle();
+			address=pn->getAddress();
+			delete pn;
+		}
 	}
 
 	AuthorName *a=publ->getPublAuthors();
@@ -550,7 +560,7 @@ void Bibliography::generateBibTex() {
 				bt.article("Ref"+QString().setNum(publ->id()),
 								"", 							/* author */
 								"",								/* title */
-								publisher, 				/* journal */
+								publ->getTitle(), 				/* journal */
 								publ->getYear(),
 								publ->getVolume(),
 								publ->getNumber(),
@@ -618,7 +628,6 @@ void Bibliography::generateBibTex() {
 	}
 	bibtex->setText(bt.getEntry());
 	delete a;
-	delete pn;
 }
 
 
