@@ -24,6 +24,7 @@
 #include <qpainter.h>
 #include <qmessagebox.h>
 #include <qapplication.h>
+#include <qwhatsthis.h>
 
 // include files for KDE
 #include <kiconloader.h>
@@ -44,6 +45,7 @@
 #include "publication.h"
 #include "bibliography.h"
 #include "publisher.h"
+#include "journalview.h"
 #include "part.h"
 #include "partmemo.h"
 #include "dataview.h"
@@ -56,6 +58,8 @@
 #include "searchoptions.h"
 #include "parser.h"
 #include "export.h"
+#include "publisherselect.h"
+#include "journalselect.h"
 #include <sys/types.h>
 #include <sys/time.h>
 #include <kstdaction.h>
@@ -187,11 +191,14 @@ void KaspalisteApp::initAction()
   actAuthorOverview = new KAction( "Author Overview", 0, this, SLOT(slotAuthorOverview()), actionCollection(), "author_overview");
   actNoteOverview = new KAction( "Note Overview", 0, this, SLOT(slotNoteOverview()),  actionCollection(), "note_overview");
   actPublOverview = new KAction( "Publication Overview", 0, this, SLOT(slotPublOverview()), actionCollection(), "publ_overview");
+  actPublisherOverview = new KAction( "Publisher Overview", 0, this, SLOT(slotPublisherOverview()), actionCollection(), "publisher_overview");
+  actJournalOverview = new KAction( "Journal Overview", 0, this, SLOT(slotJournalOverview()), actionCollection(), "journal_overview");
 
   actNewAuthor = new KAction( "New Author", 0, this, SLOT(slotNewAuthor()), actionCollection(), "new_author");
   actNewNote   = new KAction( "New Note", 0, this, SLOT(slotNewNote()),  actionCollection(), "new_note");
   actNewPublication = new KAction( "New Publication", 0, this, SLOT(slotNewPublication()), actionCollection(), "new_publication");
   actNewPublisher   = new KAction( "New Publisher", 0, this, SLOT(slotNewPublisher()), actionCollection(), "new_publisher");
+  actNewJournal   = new KAction( "New Journal", 0, this, SLOT(slotNewJournal()), actionCollection(), "new_journal");
 
   actSearch     = new KAction( "Search", 0, this, SLOT(slotSearch()), actionCollection(), "start_search");
   actBuildIndex = new KAction( "Build Index", 0, this, SLOT(slotBuildIndex()), actionCollection(), "build_index");
@@ -214,6 +221,15 @@ void KaspalisteApp::initToolBar()
 {
  	toolBar()->insertLined("", ID_URLLINE, SIGNAL(returnPressed()), this, SLOT(slotSetToolbarURL()));
  	urlline=toolBar()->getLined(ID_URLLINE);
+	QWhatsThis::add(urlline,	i18n("Kaspaliste works like a browser. The different views behave like documents " \
+																 "and they take a where clause formulated in sql as a parameter. " \
+																 "The where clause applies to the underlying database table. This is a very " \
+																 "flexible feature. Some knowledge about the database structure is required but it " \
+																 "allows quite complex queries. The table structure can be found in the create.tables.sql " \
+																 "file in the kaspaliste distribution.\n" \
+																 "The name of the view is followed by a '#' for the where clause or a '?' for a " \
+																 "a command. A command is for example 'new'. The url 'kaspa://publication?new' " \
+																 "creates a new publication.")); 	
 	connect(urlline, SIGNAL(completion(void)),SLOT(slotNextFocus(void)));
 	toolBar()->setItemAutoSized(ID_URLLINE);
 }
@@ -498,6 +514,14 @@ void KaspalisteApp::slotPublOverview() {
   slotSetURL("kaspa://publicationoverview#order by title", false);
 }
 
+void KaspalisteApp::slotPublisherOverview() {
+  slotSetURL("kaspa://publisheroverview#order by name", false);
+}
+
+void KaspalisteApp::slotJournalOverview() {
+  slotSetURL("kaspa://journaloverview#order by name", false);
+}
+
 void KaspalisteApp::slotNewAuthor() {
   slotSetURL("kaspa://author?new", false);
 }
@@ -514,6 +538,11 @@ void KaspalisteApp::slotNewPublisher() {
   slotSetURL("kaspa://publisher?new", false);
 }
 
+void KaspalisteApp::slotNewJournal() {
+  slotSetURL("kaspa://journal?new", false);
+}
+
+
 void KaspalisteApp::slotSearch() {
   slotSetURL("kaspa://search", false);
 }
@@ -534,6 +563,32 @@ bool KaspalisteApp::showAuthorOverview(KaspaURL url, const char *caption) {
   return true;
 }
 
+bool KaspalisteApp::showPublisherOverview(KaspaURL url, const char *caption) {
+  try {
+		if(!cleanupView()) return false;
+    view = new PublisherSelect(url, conn, caption?caption:"Publisher", this);
+		setupView(selbackgr);
+  }  catch(KaspaErr& err) {
+		HANDLE_CATCH(err);
+		return false;
+  }
+  return true;
+}
+
+
+bool KaspalisteApp::showJournalOverview(KaspaURL url, const char *caption) {
+  try {
+		if(!cleanupView()) return false;
+    view = new JournalSelect(url, conn, caption?caption:"Journal", this);
+		setupView(selbackgr);
+  }  catch(KaspaErr& err) {
+		HANDLE_CATCH(err);
+		return false;
+  }
+  return true;
+}
+
+
 bool KaspalisteApp::showPublOverview(KaspaURL url, const char *caption) {
   try {
 		if(!cleanupView()) return false;
@@ -661,6 +716,19 @@ bool KaspalisteApp::showPublisher(KaspaURL url) {
   return true;
 }
 
+bool KaspalisteApp::showJournal(KaspaURL url) {
+  try {
+		if(!cleanupView()) return false;
+
+    view = new JournalView(url, conn, this, "Journal");
+		setupView(publisherbackgr);
+  } catch(KaspaErr& err) {
+		HANDLE_CATCH(err);
+		return false;
+  }
+  return true;
+}
+
 bool KaspalisteApp::showEditPartData(KaspaURL url) {
   try {
 		if(!cleanupView()) return false;
@@ -718,6 +786,8 @@ bool KaspalisteApp::event(QEvent *e) {
     if(!strcmp(url.table(), "publication")) showPublication(url);
 
     if(!strcmp(url.table(), "publisher")) showPublisher(url);
+
+    if(!strcmp(url.table(), "journal")) showJournal(url);
 		
     if(!strcmp(url.table(), "bibliography")) showBibliography(url);
 		
@@ -735,6 +805,10 @@ bool KaspalisteApp::event(QEvent *e) {
 
     if(!strcmp(url.table(), "publicationoverview")) showPublOverview(url, "Publication Overview");
 
+    if(!strcmp(url.table(), "publisheroverview")) showPublisherOverview(url, "Publisher Overview");
+
+    if(!strcmp(url.table(), "journaloverview")) showJournalOverview(url, "Journal Overview");
+
     if(!strcmp(url.table(), "editpartdata")) showEditPartData(url);
 
     if(!strcmp(url.table(), "search")) showSearch(url);
@@ -939,10 +1013,13 @@ void KaspalisteApp::slotInvalidGUI() {
 	actAuthorOverview->setEnabled(true);
 	actNoteOverview->setEnabled(true);
 	actPublOverview->setEnabled(true);
+	actPublisherOverview->setEnabled(true);
+	actJournalOverview->setEnabled(true);
 	actNewAuthor->setEnabled(true);
 	actNewNote->setEnabled(true);
 	actNewPublication->setEnabled(true);
 	actNewPublisher->setEnabled(true);
+	actNewJournal->setEnabled(true);
 	actSearch->setEnabled(true);
 	actBuildIndex->setEnabled(true);
 	actOptionBackground->setEnabled(true);
@@ -968,10 +1045,13 @@ void KaspalisteApp::slotWorkingGUI() {
 	actAuthorOverview->setEnabled(false);
 	actNoteOverview->setEnabled(false);
 	actPublOverview->setEnabled(false);
+	actPublisherOverview->setEnabled(false);
+	actJournalOverview->setEnabled(false);	
 	actNewAuthor->setEnabled(false);
 	actNewNote->setEnabled(false);
 	actNewPublication->setEnabled(false);
 	actNewPublisher->setEnabled(false);
+	actNewJournal->setEnabled(false);
 	actSearch->setEnabled(false);
 	actBuildIndex->setEnabled(false);
 	actOptionBackground->setEnabled(false);
@@ -997,10 +1077,13 @@ void KaspalisteApp::slotReadWriteGUI() {
 	actAuthorOverview->setEnabled(true);
 	actNoteOverview->setEnabled(true);
 	actPublOverview->setEnabled(true);
+	actPublisherOverview->setEnabled(true);
+	actJournalOverview->setEnabled(true);	
 	actNewAuthor->setEnabled(true);
 	actNewNote->setEnabled(true);
 	actNewPublication->setEnabled(true);
 	actNewPublisher->setEnabled(true);
+	actNewJournal->setEnabled(true);
 	actSearch->setEnabled(true);
 	actBuildIndex->setEnabled(true);
 	actOptionBackground->setEnabled(true);
@@ -1026,10 +1109,13 @@ void KaspalisteApp::slotReadOnlyGUI() {
 	actAuthorOverview->setEnabled(true);
 	actNoteOverview->setEnabled(true);
 	actPublOverview->setEnabled(true);
+	actPublisherOverview->setEnabled(true);
+	actJournalOverview->setEnabled(true);
 	actNewAuthor->setEnabled(true);
 	actNewNote->setEnabled(true);
 	actNewPublication->setEnabled(true);
 	actNewPublisher->setEnabled(true);
+	actNewJournal->setEnabled(true);
 	actSearch->setEnabled(true);
 	actBuildIndex->setEnabled(true);
 	actOptionBackground->setEnabled(true);
